package state51::Job;
use state51::Moose;
use MooseX::Storage;
with Storage (format => "JSON");
use MooseX::Types::Moose qw/ Str Undef /;

# Log::Message::Structured adds some base attributes for date/hostname/epochtime
# and sets the defaults

our $VERSION = '2022062300';

has date => (
    isa => Str,
    is  => 'rw',
    documentation => 'A timestamp indicating when the job was raised. Defaults to now.'
);

has correlation_id => (
    isa => Undef|Str,
    is  => 'rw',
    documentation => 'The correlation id pulled from the props on the message which raised the job.'
);

# needed by state51::Mixin::HandleOrdersOnJobs
sub BUILD {}

sub run { die 'Abstract parent class' }

with qw/
    state51::Mixin::JobLogger
    state51::Mixin::HasLogger
    state51::Mixin::Loggable
    state51::Mixin::UnloadAfterJob
/;

__PACKAGE__->meta->make_immutable;
1;

