package state51::Job::CreateTransferDetailKeys;
use Moose;
use MooseX::Types::Moose qw/ ArrayRef Str Int HashRef /;
extends 'state51::Job';

has 'private_key_id' => (
    isa     => Int,
    is      => 'ro',
    default => sub { [] },
    documentation =>
'The instance id of the stored private key. This is missing the instance id.'
);

has 'public_key_id' => (
    isa     => Int,
    is      => 'ro',
    default => sub { [] },
    documentation =>
'The instance id of the stored public key. This is missing the instance id.'
);

has 'transfer_detail_id' => (
    isa     => Int,
    is      => 'ro',
    default => sub { [] },
    documentation =>
'The instance id of the transfer details which relate to the public and private keys.'
);

sub exchange_name {
   'transfer_details_files'
}

sub suppress_console_display { 1 }

sub run {
    my ($self) = @_;
    state51::Base->connect;

    $self->associate_files_with_td();

    return 1;
}

sub associate_files_with_td {
    my ($self) = @_;

    my $td =
      state51::TransferDetails->load_polymorphic($self->transfer_detail_id());
    my $private_file = state51::File->load_polymorphic($self->private_key_id());
    my $public_file  = state51::File->load_polymorphic($self->public_key_id());

    if ($td->ssh_key_file_private or $td->ssh_key_file_public) {
        my $message = 'Cannot set new keyfile on a td that already has one. Explicity remove them first ' . $td->id;
        $self->log_message(
            level   => 'fatal',
            message => [ $message ]
        );
        die($message);
    }

    $td->ssh_key_file_private($private_file);
    $td->ssh_key_file_public($public_file);
    $td->update();

    $self->log_message("Public and Private key files added to ".$td->id());
}

__PACKAGE__->meta->make_immutable;
__PACKAGE__->new_with_options->run unless caller;
1;
