package state51::Job::EmailBounce;
use state51::Moose;
use MooseX::Storage;
use MooseX::Types::Moose qw/ Int /;
use state51::Logger;
use state51::Logger::Event::Bounce;

extends 'state51::Job';

sub exchange_name { 'emailbounce' }

has roleid => (
    isa      => Int,
    is       => 'ro',
    required => 1,
);

method run() {
    state51::Base->connect;
    my $logger = state51::Logger->new();
    try {
        my $role = state51::Role->load($self->roleid);
        $role->email_score_dec(3);
        $role->update;
        $logger->message(
            level   => "info",
            message => [
                state51::Logger::Event::Bounce->new(
                    email => $role->email,
                    score => $role->email_score,
                )
            ],
        );
    }
    catch {
        $logger->message(
            level   => "info",
            message => [
                "Failed to process bounce for "
                . $self->roleid . " $_"
                ],
        );
    };
}

with qw/
  state51::Script
  Log::Message::Structured
  Log::Message::Structured::Stringify::AsJSON
  state51::Mixin::UnloadAfterJob
  /;

__PACKAGE__->meta->make_immutable;
1;
