package state51::Job::ExampleJob;
use state51::Moose;

use MooseX::Types::Moose qw/ Str /;
use state51::Mail::Send;

use MooseX::ClassAttribute;
extends 'state51::Job';

class_has documentation => (
    is => 'ro',
    isa => 'Str',
    default => 'This is an example job. Send an email_to someone. The SMTP_HOST on your jobworker had better be something useful'
);

sub exchange_name { 'example_job' }

has email_to => (
    isa => Str,
    is => 'ro',
    required => 1,
    documentation => 'Email address to deliver a test mail to.'
);

method run() {
    my $mail = state51::Mail::Send->new();
    $mail->mail({
        to              => $self->email_to,
        from            => 'jobworker_'.`hostname`.'@openimp.com',
        subject         => 'test job',
        content_type    => 'text/plain; charset="utf-8"',
        raw_output      => 'test job (email_to = '.$self->email_to.') which does some stuff then emails me the result',
        attachment      => "this is the attachment",
        filename        => "report.csv",
        attachment_type => 'text/csv',
    });
}

with qw/
    state51::Mixin::JobLogger
/;

__PACKAGE__->meta->make_immutable;
__PACKAGE__->new_with_options->run unless caller;
1;

