package state51::Job::FixBrokenFile::Action;
use state51::Moose::Role;
use MooseX::Types::Moose qw/ Str Bool /;
use namespace::autoclean;

requires 'requests';

has message => (
    isa => Str,
    is => 'ro',
    required => 1,
);

has do_action => (
    isa => Bool,
    is => 'rw',
);

has log_action_to_rt => (
    isa => Bool,
    is => 'rw',
    default => 1,
);

with qw/ state51::Mixin::JobSignature /;

sub log_action {
    my ($self, $logger) = @_;

    return unless $self->log_action_to_rt;
    my @reqs = $self->requests();

    if (@reqs) {
        $logger->message("Logging to tickets:\n".$self->full_message, "trace");
    }
    else {
        $logger->message("No ticket to log message:\n".$self->full_message, "info");
    }

    foreach my $r (@reqs) {
        next if $r->status eq "complete";
        next if $r->status eq "cancelled";
        next unless $r->ticket_id();
        $logger->message("FixBrokenFile::Action: Logging to ticket #".$r->ticket_id, "info");
        if ($self->do_action) {
            if ($self->is_terminal) {
                # If there is a problem, we /open/ the ticket.  "Stalled" means that everything is fine.
                eval {
                    if ($r->get_ticket_status =~ /^(new|stalled)$/) {
                        $r->update_ticket_status('open');
                    }
                };
                if ($@) {
                    warn "FixBrokenFile::Action: ERROR Logging to ticket #" . $r->ticket_id . " $@";
                }
            }
        }
    }
    return;
}

1;

