package state51::Job::ManageAssetRemoveMFITContributors;
use Moose;
use MooseX::Types::Moose qw/ Int /;
use Moose::Util::TypeConstraints;
use MooseX::ClassAttribute;
extends 'state51::Job';

class_has documentation => (
    is  => 'ro',
    isa => 'Str',
    default =>
      'Manage state51::Asset and call the method to remove all MFIT contributors.'
);

sub exchange_name {
    'manage_asset_remove_mfit_contributors';
}

has 'asset_id' => (
    is  => 'ro',
    isa => Int,
    documentation =>
'The full instance id (including class id) of the instance to be operated on.',
    required => 1,
);

sub suppress_console_display { 1 }

sub run {
    my ($self) = @_;
    state51::Base->connect;

    $self->log_message("Job::ManageAssetRemoveMFITContributors called on "
          . $self->asset_id());
    if ($self->asset_id) {
        my $asset = state51::Asset::Recording->load($self->asset_id);

        $asset->remove_mfit_contributors();
    }

    return 1;
}

with qw/
    state51::Mixin::JobLogger
/;

__PACKAGE__->meta->make_immutable;
__PACKAGE__->new_with_options->run unless caller;
1;
