package state51::Job::ManageFormatRelatedReleaseFormat;
use Moose;
use MooseX::Types::Moose qw/ Str Int /;
use Moose::Util::TypeConstraints;
use MooseX::ClassAttribute;
extends 'state51::Job';

class_has documentation => (
    is  => 'ro',
    isa => 'Str',
    default =>
      'Manage the related_releaseformat relationship between two formats.'
);

sub exchange_name {
    'manage_format_related_releaseformat';
}

has 'action' => (
    is       => 'ro',
    isa      => enum([qw/ set remove /]),
    required => 1,
    documentation =>
"The action we are taking on the relationship currently `set` or `remove`.",
);

has 'releaseformat_id' => (
    is  => 'ro',
    isa => Int,
    documentation =>
'The full instance id (including class id) of the releaseformat to be operated on.',
    required => 1,
);

has 'related_releaseformat_id' => (
    is  => 'ro',
    isa => Int,
    documentation =>
      'The full instance id (including class id) of the related releaseformat.',
    required => 0,
);

has 'related_releaseformat_relationship_type' => (
    is  => 'ro',
    isa => Str,
    documentation =>
      'The name of the relationship type between the two formats.',
    required => 0,
);

sub suppress_console_display { 1 }

sub run {
    my ($self) = @_;
    state51::Base->connect;

    $self->execute_action();

    return 1;
}

sub execute_action {
    my ($self) = @_;

    if ($self->action() eq 'remove') {
        $self->log_message(
"Job::ManageFormatRelatedReleaseFormat called to remove relationship for "
              . $self->releaseformat_id());
        my ($format) = state51::ReleaseFormat->load_oids($self->releaseformat_id);
        $format->remove_related_releaseformat();
    }
    elsif ($self->action() eq 'set') {
        $self->log_message("Job::ManageFormatRelatedReleaseFormat called to set relationship for "
              . $self->releaseformat_id()
              . " to "
              . $self->related_releaseformat_id());
        my ($format) = state51::ReleaseFormat->load_oids($self->releaseformat_id);
        my ($related_format) = state51::ReleaseFormat->load_oids($self->related_releaseformat_id);

        $format->set_related_releaseformat($related_format, $self->related_releaseformat_relationship_type());
    }
}

with qw/
  state51::Mixin::JobLogger
  /;

__PACKAGE__->meta->make_immutable;
__PACKAGE__->new_with_options->run unless caller;
1;
