package state51::Job::ManageTrackv2;
use Moose;
use MooseX::Types::Moose qw/ Str Int Maybe Bool /;
use Moose::Util::TypeConstraints;
use MooseX::ClassAttribute;
extends 'state51::Job';

class_has documentation => (
    is => 'ro',
    isa => 'Str',
    default => 'Manage state51::Trackv2'
);

sub exchange_name {
    'manage_trackv2'
}

has 'action' => (
    is  => 'ro',
    isa => enum([qw/ update /]),
    documentation =>
"The action we are taking on the track, currently only `update` is supported",
);

has 'track_id' => (
    is      => 'ro',
    isa     => Int,
    documentation => 'The full instance id (including class id) of the instance to be operated on.',
    required => 1,
);

has 'preview_start_time' => (
    is      => 'ro',
    isa     => Maybe[Int],
    documentation => 'The time in seconds to start the preview at.',
    required => 0,
);

has 'play_gapless' => (
    is      => 'ro',
    isa     => Maybe[Bool],
    documentation => 'Whether or not to play gapless.',
    required => 0,
);

sub suppress_console_display { 1 }

sub run {
    my ($self) = @_;
    state51::Base->connect;

    $self->execute_action();

    return 1;
}

sub execute_action {
    my ($self) = @_;

    if ($self->action() eq 'update') {
        $self->log_message(
            "Job::ManageTrackv2 called to update " . $self->track_id());
        if ($self->track_id) {
            my $track = state51::Trackv2->load($self->track_id);

            # supply the complete set!
            $track->preview_start_time($self->preview_start_time);
            $track->play_gapless($self->play_gapless);
            $track->update();
        }
    }
}

with qw/
    state51::Mixin::JobLogger
/;

__PACKAGE__->meta->make_immutable;
__PACKAGE__->new_with_options->run unless caller;
1;
