package state51::Job::ManageWatchlist;
use Moose;
use MooseX::Storage;
use MooseX::Types::Moose qw/ Maybe Int Str Bool Undef/;
use Moose::Util::TypeConstraints;
use state51::Logger;
extends 'state51::Job';

sub exchange_name { 'managewatchlist' }

has 'artist_id' => (
    isa           => Int,
    is            => 'ro',
    required      => 1,
    documentation => 'The instance id of the Artist referenced in the action.'
);

has 'watchlist_id' => (
    isa      => Int,
    is       => 'ro',
    required => 1,
    documentation =>
      'The instance id of the watchlist referenced in the action.'
);

has 'action' => (
    is  => 'ro',
    isa => enum([qw/ add remove /]),
    documentation =>
      "The action we are taking on the state51::Target; add or remove",
);

sub run {
    my ($self) = @_;
    state51::Base->connect;

    my $artist    = state51::Artist->load($self->artist_id);
    my $watchlist = state51::Target->load($self->watchlist_id);

    if ($self->action eq 'add') {
        my $target_entry = state51::TargetEntry->fetch_or_create(
            entry  => $artist,
            target => $watchlist
        );
        $target_entry->insert unless ($target_entry->is_persistent);
        $self->log_message(
            level   => "info",
            message => [
                    "Added Artist"
                  . $artist->id
                  . " to watchlist "
                  . $watchlist->id
            ]
        );
    }
    elsif ($self->action eq 'remove') {
        my ($target_entry) =
          state51::TargetEntry->fetch(entry => $artist, target => $watchlist);
        if ($target_entry) {
            $target_entry->erase();
        }
        $self->log_message(
            level   => "info",
            message => [
                    "Removed Artist"
                  . $artist->id
                  . " from watchlist "
                  . $watchlist->id
            ]
        );
    }

    return 1;
}

with qw/
    state51::Mixin::JobLogger
/;

__PACKAGE__->meta->make_immutable;
1;
