package state51::Job::RequestTransformsForOrder;

use state51::Base;
use Function::Parameters;
use Moose;
use Try::Tiny;
use MooseX::Types::Moose qw/ Int /;
use MooseX::Types::Common::String qw/ NonEmptySimpleStr /;
use MooseX::Storage;
with Storage (format => "JSON");
use Moose::Util::TypeConstraints;
use namespace::autoclean;
use Data::Dumper;

extends 'state51::Job';

has only_format => (
    is => 'ro',
    isa => Int,
);

sub exchange_name { 'order_request_transforms' }

method run() {
    my $notes;
    my $has_error;
    if ($self->_order_object->require_file_transforms) {
        if ($self->_order_object->status eq 'ready') {
            try {
                my $transforms_count = $self->_order_object->request_all_transforms({ ($self->only_format ? (only_format => state51::ReleaseFormat->load($self->only_format)) : ()) });
                $notes = "Generated $transforms_count Transforms for order from deliver desires\n";
            }
            catch {
                $has_error = 1;
                $notes = "Failed to generate transforms for order " . $self->order . ": $_\n";
            };
        }
        else {
            $notes = "Ignored request to generate transforms for order which is in status " . $self->_order_object->status . " rather than 'ready'";
        }
    }
    else {
        $notes = "Should not have been asked to RequestTransformsForOrder for an order which does not require them";
        $has_error = 1;
    }
    $notes = $self->date . " $notes";

    if ($self->interactive) {
        print $notes;
        $self->log_message( level => "warn", message => ["Order id:" . $self->order . ". " . $notes]);
    }
    eval {
        $self->update_ticket_status('open') if $has_error;
    };
    if ($@) {
        $self->log_message( level => "warn", message => ["Order id:" . $self->order . ". RequestTransformsForOrder: ERROR update_ticket_status $@"]);
    }

    return !$has_error;
}

method lockname() {
    "order_requesttransforms_".$self->order;
}

with qw/
    state51::Script::Helper::InteractiveSuccess
    state51::Mixin::HandleOrdersOnJobs
    state51::Mixin::JobSignature
    state51::Mixin::LockedJob
    state51::Mixin::HasLogger
/;

#__PACKAGE__->meta->make_immutable;
__PACKAGE__->new_with_options->run unless caller;
1;
