package state51::Mixin::HandleOrdersOnJobs;
use Moose::Role;
use MooseX::Types::Common::String qw/ NonEmptySimpleStr /;
use Function::Parameters;
use Moose::Util::TypeConstraints;
use MooseX::Getopt ();
use namespace::autoclean;

has 'order' => (
    is            => 'ro',
    isa           => NonEmptySimpleStr,
    required      => 1,
    documentation => 'An export/import order id',
    traits    => [ 'Getopt' ],
    cmd_aliases => 'o',
);

sub BUILD {}
before BUILD => sub {
    state51::Base->connect;
};

class_type 'state51::Request';
has _order_object => (
    is => 'ro',
    isa => 'state51::Request',
    traits => [qw/ DoNotSerialize /],
    default => sub {
        my $self = shift;
        my ($order) = state51::Base->storage->load($self->order);
        die("Cannot find order ID " . $self->order)
            unless $order && blessed($order) && $order->isa('state51::Request');
        return $order;
    },
    lazy => 1,
    handles => {
        order_xls_to_deliver_desire => 'order_xls_to_deliver_desire',
        order_notes => 'notes',
        update_order => 'update',
        validate_service_metadata_xls => 'validate_service_metadata_xls',
        process_service_metadata_xls => 'process_service_metadata_xls',
        correspond_in_rt => 'correspond_in_rt',
        update_ticket_status => 'update_ticket_status',
        process_ppl_metadata_xls => 'process_ppl_metadata_xls',
    },
    clearer => '_clear_order_object',
    predicate => '_has_order_object',
);

# avoid races due to job A running in pid 1, firing job B which
# then runs in pid 2, which then fires job C which runs in pid 1 again
# Without unloading job C can get stale objects from Tangram cache.
after 'run' => sub {
    my $self = shift;
    if (!exists $INC{'state51/Test.pm'}) {
        $self->_order_object->unload if $self->_has_order_object;
    }
    $self->_clear_order_object;
};

sub exchange_name { 'orderxlsvalidate' }

with qw/ state51::Mixin::UnloadAfterJob /;

1;
