package state51::Mixin::JobLogger;

use Moose::Role;
use state51::Logger;
use state51::Logger::Event::JobStarted;
use state51::Logger::Event::JobCompleted;
use state51::Logger::Event::JobFailed;

use Time::HiRes qw/ gettimeofday tv_interval /;

requires 'run';

around run => sub {
    my $orig = shift;
    my $self = shift;

    my $instance = state51::Logger->instance();
    # If the job has a correlation id, use it.
    # Bit rude to poke around in the backend, maybe logger should know how to do this?
    if ($self->correlation_id) {
        my $backends = $instance->backends_by_name();
        if ($backends->{'state51::Logger::RabbitMQ'}) {
            $backends->{'state51::Logger::RabbitMQ'}->correlation_id($self->correlation_id);
        }
    }

    state51::Logger->instance->message(
        type => "trace",
        message => [state51::Logger::Event::JobStarted->new( job => $self, job_correlation_id => $self->correlation_id )],
    );

    my $start = [gettimeofday];
    my $ret;

    eval {
        $ret = $self->$orig(@_);
    };
    if ($@) {
        my $error = $@;
        state51::Logger->instance->message(
            type => "trace",
            message => [state51::Logger::Event::JobFailed->new(
                job => $self,
                duration => tv_interval($start, [gettimeofday]),
                error => $error,
                job_correlation_id => $self->correlation_id,
            )],
        );
        die $error;
    }

    state51::Logger->instance->message(
        type => "trace",
        message => [state51::Logger::Event::JobCompleted->new(
            job => $self,
            duration => tv_interval($start, [gettimeofday]),
            job_correlation_id => $self->correlation_id
        )],
    );

    return $ret;
};

1;
