package state51::Mixin::LockedJob;
use state51::Moose::Role;
use state51::Base;

requires('run', 'lockname');

with 'state51::Mixin::HasLocks';

around run => sub {
    my ($orig, $self, @args) = @_;
    state51::Base->connect;
    my $lockname = $self->lockname;
    my ($return, $ran) = (0, 0);

    if ($lockname) { # don't lock if no lockname
        $self->do_whilst_locked(
            $lockname,
            sub {
                $ran    = 1;
                $return = $self->$orig(@args);
            }
        );
        warn("Skipping job " . ref($self) . " as lock $lockname taken\n")
          if (!$ran);
    }
    else { # no lockname, so run the job without a lock
        $return = $self->$orig(@args);
    }
    return $return;
};

1;
