package state51::Mixin::RunsAsyncJobs;
use Moose::Role;
use MooseX::Types::Moose qw/Bool/;
use Function::Parameters;
use Class::MOP;
use Class::Load;
use namespace::autoclean;

has 'async' => (
    is            => 'ro',
    isa           => Bool,
    lazy          => 1,
    default => sub {
        my $self = shift;
        if ($self->can('interactive')) {
            return !!! $self->interactive;
        }
        confess("Cannot work out if I should default to async or not!");
    },
    documentation => 'Create async jobs, or run them in sync mode',
);

method run_job ($class, %p) {
    Class::Load::load_class($class);
    my $job = $class->new(async => $self->async, %p);
    if ($job->can('async') ? $job->async : $self->async) {
        $self->log_message(
            level => 'info', message => [ $job ],
        );
    }
    else {
        warn("Running job in foreground: " . $job . "\n");
        $job->run;
    }
}

with 'state51::Mixin::HasLogger';

1;

